@@ -1,4 +1,4 @@
-/* bug-buddy bug submitting program
+/*  bug-buddy bug submitting program
  *
  * Copyright (C) 2000 Jacob Berkman
  *
@@ -134,6 +134,13 @@ check_old_version (void)
 	GDateMonth month;
 	GDateYear  year;
 	GDate *gnome_date, *current_date;
+	static gboolean checked = FALSE;
+
+	if (checked == TRUE) {
+		return FALSE;
+	} else {
+		checked = TRUE;
+	}
 
 	if (druid_data.gnome_date) {
 		year = atoi (strtok (druid_data.gnome_date, "-"));
@@ -248,6 +255,7 @@ void invalid_description (void) {
        	gtk_widget_destroy (w);
 }
 
+
 void
 druid_set_state (BuddyState state)
 {
@@ -267,7 +275,10 @@ druid_set_state (BuddyState state)
 	oldstate = druid_data.state;
 	druid_data.state = state;
 
-	druid_set_sensitive ((state > 0), (state < STATE_FINISHED), TRUE);
+	druid_set_sensitive ((state != STATE_INTRO && 
+			      (state != STATE_GDB || 
+			       druid_data.bug_type != BUG_CRASH)),
+			     (state < STATE_FINISHED), TRUE);
 
 	{
 		GtkLabel *label = GTK_LABEL (GET_WIDGET ("druid-label"));
@@ -970,16 +981,22 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 			break;
 		
 		application = g_hash_table_lookup(druid_data.program_to_application, druid_data.current_appname);
-		if (!application || !application->bugzilla || !application->product)
+		if (!application || !application->bugzilla || !application->product) {
+			products_list_load ();
 			break;
+		}
 
 		bts = g_hash_table_lookup (druid_data.bugzillas, application->bugzilla);
-		if (!bts)
+		if (!bts) {
+			products_list_load ();
 	       		break;
+		}
 		
 		product = g_hash_table_lookup (bts->products, application->product);
-		if (!product)
+		if (!product) {
+			products_list_load ();
 			break;
+		}
 		
 		druid_data.product = product;
 		bugzilla_product_add_components_to_clist (druid_data.product);
@@ -1154,23 +1171,7 @@ on_druid_next_clicked (GtkWidget *w, gpointer data)
 
 void
 on_druid_cancel_clicked (GtkWidget *w, gpointer data)
-{
-	GtkWidget *d;
-
-	d = gtk_message_dialog_new (GTK_WINDOW (GET_WIDGET ("druid-window")),
-				    0,
-				    GTK_MESSAGE_QUESTION,
-				    GTK_BUTTONS_YES_NO,
-				    _("Are you sure you want to cancel\n"
-				      "this bug report?"));
-	gtk_dialog_set_default_response (GTK_DIALOG (d),
-					 GTK_RESPONSE_YES);
-	if (GTK_RESPONSE_YES != gtk_dialog_run (GTK_DIALOG (d))) {
-		gtk_widget_destroy (d);
-		return;
-	}
-	gtk_widget_destroy (d);
-
+{       
 	stop_gdb ();
 	gtk_main_quit ();
 }
